@@ -696,7 +696,7 @@ WCS_details <- function(wcs = c('mukey', 'ISSR800', 'soilColor')) {
   'hi_ssurgo' = list(
     dsn = 'hi_ssurgo',
     type = 'GEOTIFF_FLOAT',
-    desc = 'HI map unit keys (experimental)',
+    desc = 'HI map unit keys',
     vintage = 'FY2024',
     na = 4294967295,
     res = 30,
@@ -706,7 +706,7 @@ WCS_details <- function(wcs = c('mukey', 'ISSR800', 'soilColor')) {
   'pr_ssurgo' = list(
     dsn = 'pr_ssurgo',
     type = 'GEOTIFF_FLOAT',
-    desc = 'PR map unit keys (experimental)',
+    desc = 'PR map unit keys',
     vintage = 'FY2024',
     na = 4294967295,
     res = 30,
