@@ -12,7 +12,7 @@
 #' @param dsn Optional: path to local SQLite database containing NASIS table structure; default:
 #'   `NULL`
 #'
-#' @return A named list containing: "vegplot", "vegplotlocation", "vegplotrhi", "vegplotspecies",
+#' @return `fetchVegdata()`: A named list containing: "vegplot", "vegplotlocation", "vegplotrhi", "vegplotspecies",
 #'   "vegtransect", "vegtransplantsum", 'vegsiteindexsum', "vegsiteindexdet", "vegbasalarea", and
 #'   "vegplottext" tables
 #'
@@ -29,26 +29,31 @@ fetchVegdata <- function(SS = TRUE, include_pedon = TRUE, stringsAsFactors = NUL
     NASISDomainsAsFactor(stringsAsFactors)
   }
 
-
   # check if NASIS local DB instance/ODBC data source is available
   .soilDB_test_NASIS_connection(dsn = dsn)
 
 	# 1. load data in pieces
-  site <- get_site_data_from_NASIS_db(SS = SS, include_pedon = ifelse(include_pedon == "assocuserpedonid", TRUE, include_pedon), dsn = dsn)
+  site <- get_site_data_from_NASIS_db(
+    SS = SS,
+    include_pedon = ifelse(include_pedon == "assocuserpedonid", TRUE, include_pedon),
+    dsn = dsn
+  )
   vegplot <- get_vegplot_from_NASIS_db(SS = SS, dsn =  dsn)
-  vegplotlocation <- get_vegplot_location_from_NASIS_db(SS = SS,  dsn =  dsn)
+  vegplotlocation <- get_vegplot_location_from_NASIS_db(SS = SS, dsn =  dsn)
   vegplotrhi <-  get_vegplot_trhi_from_NASIS_db(SS = SS, dsn =  dsn)
   vegplotspecies <- get_vegplot_species_from_NASIS_db(SS = SS, dsn =  dsn)
   vegtransect <- get_vegplot_transect_from_NASIS_db(SS = SS, dsn =  dsn)
   vegtransplantsum <- get_vegplot_transpecies_from_NASIS_db(SS = SS, dsn =  dsn)
   vegtranspoint <- get_vegplot_transpoints_from_NASIS_db(SS = SS, dsn = dsn)
+  veggroundsurface <- get_vegplot_groundsurface_from_NASIS_db(SS = SS, dsn = dsn)
   vegprodquadrat <- get_vegplot_prodquadrats_from_NASIS_db(SS = SS, dsn =  dsn)
-  vegsiteindexsum <- get_vegplot_tree_si_summary_from_NASIS_db(SS = SS, dsn =  dsn)
-  vegsiteindexdet <- get_vegplot_tree_si_details_from_NASIS_db(SS = SS, dsn =  dsn)
+  vegsiteindexsum <- get_vegplot_tree_si_summary_from_NASIS_db(SS = SS, dsn = dsn)
+  vegsiteindexdet <- get_vegplot_tree_si_details_from_NASIS_db(SS = SS, dsn = dsn)
   vegbasalarea <- get_vegplot_speciesbasalarea_from_NASIS(SS = SS, dsn =  dsn)
-  vegplottext <-  get_vegplot_textnote_from_NASIS_db(SS = SS, fixLineEndings = TRUE, dsn =  dsn)
-
-
+  vegplottext <-  get_vegplot_textnote_from_NASIS_db(SS = SS,
+                                                     fixLineEndings = TRUE,
+                                                     dsn =  dsn)
+  
 	# test to see if the selected set is loaded
 	if (nrow(site) == 0 || nrow(vegplot) == 0) {
 	  message('Selected set is missing either the vegplot, pedon or site table, please load and try again :)')
@@ -78,6 +83,7 @@ fetchVegdata <- function(SS = TRUE, include_pedon = TRUE, stringsAsFactors = NUL
       vegtransect = vegtransect,
       vegtransplantsum = vegtransplantsum,
       vegtranspoint = vegtranspoint,
+      veggroundsurface = veggroundsurface,
       vegprodquadrat = vegprodquadrat,
       vegsiteindexsum = vegsiteindexsum,
       vegsiteindexdet = vegsiteindexdet,
