@@ -7,7 +7,7 @@
 #' @param dsn Optional: path to local SQLite database containing NASIS
 #' table structure; default: NULL
 #' @return A data.frame containing problematic records with columns:
-#' 'peiid','pedon_id','hzdept','hzdepb','hzname'
+#' 'peiid','upedonid','hzdept','hzdepb','hzname'
 #' @export 
 getHzErrorsNASIS <- function(strict = TRUE, SS = TRUE, dsn = NULL) {
 
@@ -17,17 +17,17 @@ getHzErrorsNASIS <- function(strict = TRUE, SS = TRUE, dsn = NULL) {
   
 	# get data
 	site_data <- get_site_data_from_NASIS_db(SS = SS, dsn = dsn)
-	site_data$pedon_id <- NULL
+	site_data$upedonid <- NULL
 	hz_data <- get_hz_data_from_NASIS_db(SS = SS, dsn = dsn)
 
 	if (nrow(site_data) == 0) {
 	  message("No Site records in NASIS database")
-  	return(data.frame(pedon_id = character(0), valid = logical(0)))
+  	return(data.frame(upedonid = character(0), valid = logical(0)))
 	}
 
 	if (nrow(hz_data) == 0) {
 	  message("No Pedon Horizon records in NASIS database")
-	  return(data.frame(pedon_id = character(0), valid = logical(0)))
+	  return(data.frame(upedonid = character(0), valid = logical(0)))
 	}
 
 	# combine pieces
@@ -36,10 +36,10 @@ getHzErrorsNASIS <- function(strict = TRUE, SS = TRUE, dsn = NULL) {
 	f.test <- aqp::checkHzDepthLogic(f, hzdepths = c('hzdept', 'hzdepb'), idname = 'peiid', fast = TRUE)
 
 	# find bad ones
-	bad.pedon.ids <- as.character(f.test$pedon_id[which(f.test$valid == FALSE)])
+	bad.pedon.ids <- as.character(f.test$upedonid[which(f.test$valid == FALSE)])
 
 	# now describe the problems
-	b <- f[which(f$pedon_id %in% bad.pedon.ids), c('peiid', 'pedon_id','hzdept','hzdepb','hzname')]
+	b <- f[which(f$pedon_id %in% bad.pedon.ids), c('peiid', 'upedonid','hzdept','hzdepb','hzname')]
 
 	return(b)
 
