@@ -1,10 +1,9 @@
 context("fetchSDA() -- requires internet connection")
 
-## sample data: these should run in < 3 seconds
-
-
 test_that("fetchSDA() works", {
   
+  skip_if_not_installed("aqp")
+  
   skip_if_not_installed("httr")
   
   skip_if_offline()
@@ -22,6 +21,8 @@ test_that("fetchSDA() works", {
 
 test_that("fetchSDA() returns an SPC", {
   
+  skip_if_not_installed("aqp")
+  
   skip_if_not_installed("httr")
   
   skip_if_offline()
@@ -29,33 +30,39 @@ test_that("fetchSDA() returns an SPC", {
   skip_on_cran()
 
   # SPC integrity and expected IDs / hz depths
-  expect_equal(idname(x), 'cokey')
-  expect_equal(horizonDepths(x), c('hzdept_r', 'hzdepb_r'))
+  expect_equal(aqp::idname(x), 'cokey')
+  expect_equal(aqp::horizonDepths(x), c('hzdept_r', 'hzdepb_r'))
 
 })
 
 test_that("fetchSDA() returns expected results", {
   
+  skip_if_not_installed("aqp")
+  
   skip_if_not_installed("httr")
   
   skip_if_offline()
 
   skip_on_cran()
 
+  library(aqp)
+  
   # there should be 2 components and 10 horizons
-  expect_equal(length(x), 2)
-  expect_equal(nrow(x), 10)
+  expect_equal(nrow(aqp::site(x)), 2)
+  expect_equal(aqp::nrow(x), 10)
 
   # should match original WHERE clause
   expect_equal(x$nationalmusym, c('kzc4', 'kzc4'))
-  expect_equal(site(x)$nationalmusym, c('kzc4', 'kzc4'))
+  expect_equal(aqp::site(x)$nationalmusym, c('kzc4', 'kzc4'))
 
   # test that both components have no NRCS forest/range site assigned
-  expect_contains(site(x)$ecoclassid, c("F114XB104IN", "F114XA101IN"))
+  expect_contains(aqp::site(x)$ecoclassid, c("F114XB104IN", "F114XA101IN"))
 })
 
 test_that("fetchSDA(duplicates=TRUE) works as expected", {
   
+  skip_if_not_installed("aqp")
+  
   skip_if_not_installed("httr")
   
   skip_if_offline()
