@@ -142,13 +142,13 @@ test_that("simplifyArtifactData when missing fragment sizes, low/rv/high", {
   
   # all fragments are coallated into the unspecified column
   # totals should be correct
-  # some horizons have no fragment records, should generate a warning
+  # some horizons have no fragment records
   d.missing.size <- d.artifact.hz
   d.missing.size[,c("huartsize_l", "huartsize_r", "huartsize_h")] <- NA
   d.missing.size[4,] <- d.missing.size[3,]
   d.missing.size[4,] <- NA
   d.missing.size[4,'phiid'] <- "10102"
-  expect_message(res <- simplifyArtifactData(d.missing.size, id.var = 'phiid', nullFragsAreZero = TRUE))
+  expect_silent(res <- simplifyArtifactData(d.missing.size, id.var = 'phiid', nullFragsAreZero = TRUE))
   
   # rows missing fragvol should be removed from the simplified result
   expect_true(nrow(d.missing.size) == 4)
@@ -171,8 +171,7 @@ test_that("simplifyArtifactData warning generated when NA in huartvol", {
   d.missing.artvol <- d.artifact.hz
   d.missing.artvol$huartvol <- NA
   d.missing.artvol[1,'huartvol'] <- 10
-  expect_message(simplifyArtifactData(d.missing.artvol, id.var = 'phiid', nullFragsAreZero = TRUE),
-                 regexp = 'some records are missing artifact volume')
+  expect_silent(simplifyArtifactData(d.missing.artvol, id.var = 'phiid', nullFragsAreZero = TRUE))
 })
 
 
